Sequential (then) combinators for OutOf parsers.
These combinators compose parsers in order on the same In stream.
They do not perform rollback by themselves.
Rollback / backtracking is provided by higher-level combinators such as:
crate::parser::choice::Choice(tries next branch only on non-cut failure)crate::input::In::maybe
Interaction with cut
This crate treats cut as an explicit branch-pruning marker.
If you want a successful prefix to commit, wrap it with
crate::parser::ParserOnce::cut or insert crate::parser::prim::cut.
Structs
- Between
- Parse
left, theninner, thenright, returning theinneroutput. - Bind
- Sequential bind (flat_map).
- Left
- Keep the left output and discard the right output.
- Map
- Map the output of a parser.
- Right
- Parser that discards the left output and keeps the right output.
- To
- Replace the output of a parser with a constant value.